==> Paws-0.23.tar.gz: Paws-0.23/lib/Paws/EC2/DeleteFlowLogs.pm <==

package Paws::EC2::DeleteFlowLogs;
  use Moose;
  has FlowLogIds => (is => 'ro', isa => 'ArrayRef[Str]', traits => ['NameInRequest'], request_name => 'FlowLogId' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteFlowLogs');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DeleteFlowLogsResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DeleteFlowLogs - Arguments for method DeleteFlowLogs on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteFlowLogs on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method DeleteFlowLogs.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteFlowLogs.

As an example:

  $service_obj->DeleteFlowLogs(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> FlowLogIds => ArrayRef[Str]

One or more flow log IDs.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteFlowLogs in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/EC2/DeleteFlowLogs.pm <==

package Paws::EC2::DeleteFlowLogs;
  use Moose;
  has FlowLogIds => (is => 'ro', isa => 'ArrayRef[Str|Undef]', traits => ['NameInRequest'], request_name => 'FlowLogId' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteFlowLogs');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DeleteFlowLogsResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DeleteFlowLogs - Arguments for method DeleteFlowLogs on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteFlowLogs on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method DeleteFlowLogs.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteFlowLogs.

As an example:

  $service_obj->DeleteFlowLogs(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> FlowLogIds => ArrayRef[Str|Undef]

One or more flow log IDs.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteFlowLogs in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
